#!/bin/bash

FVWMCOMMAND=`which FvwmCommand`

if [ -z $FVWMCOMMAND ] ; then
echo "ERROR: FvwmCommand not found"
exit 1
fi

# Rotate the screen to landscape
MODEL=`cat /proc/deviceinfo/product`
ROTA=`xrandr | grep 'Current rotation' | sed -e 's/Current rotation\ \-\ //g'`
case "$MODEL" in
    SL-6000)
        /usr/X11R6/bin/xrandr -o left
        ;;
    *)
        if [ -e $HOME/.fvwm/closed ] && [ "$ROTA" == "normal" ] ; then
	    # This is true when closed -> opened
	    rm $HOME/.fvwm/closed
	    exit 0
	else
	    # This is true when portrait -> landscape
	    /usr/X11R6/bin/xrandr -o normal
	fi
        echo "100" >/proc/driver/w100/fastsysclk
        ;;
esac

# Set the landscape style background picture
fvwm-root -r /usr/share/pixmaps/fvwm/tux1-landscape.png

# We set the size of the maximized windows
$FVWMCOMMAND "KillModule FvwmButtons ZaurusTaskbar"
$FVWMCOMMAND "DestroyFunc ZaurusMaximize"
$FVWMCOMMAND "AddToFunc ZaurusMaximize I Maximize \$0 640p 448p"

# This is the definiton for the landscape taskbar
$FVWMCOMMAND "DestroyModuleConfig ZaurusTaskbar: *"
$FVWMCOMMAND "*ZaurusTaskbar: ButtonGeometry 16x32+0-0"
$FVWMCOMMAND "*ZaurusTaskbar: Colorset 3"
$FVWMCOMMAND "*ZaurusTaskbar: Frame 0"
$FVWMCOMMAND "*ZaurusTaskbar: Padding 0 0"
$FVWMCOMMAND "*ZaurusTaskbar: Rows 1"
$FVWMCOMMAND "#*ZaurusTaskbar: Columns 40"
$FVWMCOMMAND "*ZaurusTaskbar: (2x1, Icon mbmenu.png, Action Schedule 50 Popup MenuFvwmRoot Rectangle +\$left+\$top 0 -100m)"
#$FVWMCOMMAND "*ZaurusTaskbar: (2x1, Icon 32x32/konsole.png, Action Schedule 50 Exec exec xterm -bg black -fg white -geometry 68x23+0+0 -fn -misc-fixed-medium-r-normal--18-*)"
$FVWMCOMMAND "*ZaurusTaskbar: (2x1, Icon 32x32/konsole.png, Action Schedule 50 Exec exec aterm -bg black -fg green -geometry 80x25 -fn -misc-fixed-medium-r-normal--14-*)"
$FVWMCOMMAND "*ZaurusTaskbar: (29x1, Swallow FvwmIconMan \`FvwmIconMan\`)"
$FVWMCOMMAND "*ZaurusTaskbar: (7x1, Right, Swallow (Respawn) ztaskbar \`/usr/bin/fvwm-ztaskbar\`)"

$FVWMCOMMAND "Module FvwmButtons ZaurusTaskbar"
$FVWMCOMMAND "All (Maximized) ZaurusMaximize true"

